# How to use DocumenterCitations.jl

DocumenterCitations.jl uses [Bibliography.jl](https://github.com/Azzaare/Bibliography.jl) to add support for BibTeX citations and references in documentation pages generated by [Documenter.jl](https://github.com/JuliaDocs/Documenter.jl).

DocumenterCitations.jl is still in early development so please open issues if you encounter any bugs or pain points, would like to see a new feature, or if you have any questions.

## Installation instructions

You can install the latest version of DocumenterCitations.jl using the built-in package manager (accessed by pressing `]` in the
Julia command prompt) to add the package and instantiate/build all dependencies

```julia
julia>]
(v1.5) pkg> add DocumenterCitations
```

## Telling Documenter.jl about your bibliography

You just need a BibTeX `.bib` file to get started! Let's call it `some_references.bib`. You want to create a `CitationBibliography` and pass it to `makedocs`:

```julia
using DocumenterCitations

bib = CitationBibliography("some_references.bib")
makedocs(bib, ...)
```

## How to get a sorted References list

In order to get a sorted references list you can pass a additional `sorting` argument to `CitationBibliography()`.

```julia
bib = CitationBibliography("some_references.bib", sorting = :nyt)
```

The currently supported sorting orders and their behaviours are managed by [`Bibliography.sorting_rules`](https://humans-of-julia.github.io/Bibliography.jl/stable/#Bibliography.sorting_rules).

## How to cite references in your documentation

You can now use citations anywhere in your docs!

Here I cite `Mayer2012`, a useful article, via `[Mayer2012](@cite)`: [Mayer2012](@cite).

I also cite `useful_proof`, a book you might not want to read, with `[useful_proof](@cite)` [useful_proof](@cite).

Some TeX diacritical marks are supported, e.g. [Heun1900](@cite).

Clicking on the citations takes you to the bibliography.

# Example

```@docs
DocumenterCitations.Example
```
